<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::table('admins', function (Blueprint $table) {
            $table->string('mobile')->nullable()->after('email');
            $table->string('pass_code')->nullable()->after('password');
            $table->unsignedInteger('status')->default(1)->after('mobile');
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::table('admins', function (Blueprint $table) {
            // $table->dropColumn('status');
            $table->dropColumn('pass_code');
            $table->dropColumn('mobile');
        });
    }
};
